decrypt
[metze/wireshark/wip.git] / file.h
diff --git a/file.h b/file.h
index 5e1da43ebfd5136c364d678b84fd350254d744f7..090528654b143cc7f0e7dd590958274579e54cbd 100644 (file)
--- a/file.h
+++ b/file.h
@@ -5,16 +5,16 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * SPDX-License-Identifier: GPL-2.0+
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef __FILE_H__
 #define __FILE_H__
 
-#include "wiretap/wtap.h"
 #include <errno.h>
-#include <epan/epan.h>
 
+#include <wiretap/wtap.h>
+#include <epan/epan.h>
 #include <epan/print.h>
 #include <ui/packet_range.h>
 
@@ -63,18 +63,11 @@ typedef enum {
     cf_cb_file_retap_finished,
     cf_cb_file_merge_started, /* Qt only */
     cf_cb_file_merge_finished, /* Qt only */
-    cf_cb_file_fast_save_finished, /* GTK+ only? */
-    cf_cb_packet_selected, /* GTK+ only. */
-    cf_cb_packet_unselected, /* GTK+ only. */
-    cf_cb_field_unselected, /* GTK+ only. */
+    cf_cb_file_fast_save_finished,
     cf_cb_file_save_started,
     cf_cb_file_save_finished,
     cf_cb_file_save_failed,
-    cf_cb_file_save_stopped,
-    cf_cb_file_export_specified_packets_started, /* GTK+ only. */
-    cf_cb_file_export_specified_packets_finished, /* GTK+ only. */
-    cf_cb_file_export_specified_packets_failed, /* GTK+ only. */
-    cf_cb_file_export_specified_packets_stopped /* GTK+ only. */
+    cf_cb_file_save_stopped
 } cf_cbs;
 
 typedef void (*cf_callback_t) (gint event, gpointer data, gpointer user_data);
@@ -152,13 +145,13 @@ cf_read_status_t cf_read(capture_file *cf, gboolean from_save);
  *
  * @param cf the capture file from which to read the record
  * @param fdata the frame_data structure for the record in question
* @param phdr pointer to a wtap_pkthdr structure to contain the
  * record's metadata
  * @param buf a Buffer into which to read the record's raw data
  * @return TRUE if the read succeeded, FALSE if there was an error
  */
 gboolean cf_read_record_r(capture_file *cf, const frame_data *fdata,
-                          struct wtap_pkthdr *phdr, Buffer *buf);
+                          wtap_rec *rec, Buffer *buf);
 
 /**
  * Read the metadata and raw data for a record into a
@@ -282,6 +275,17 @@ cf_write_status_t cf_export_specified_packets(capture_file *cf,
  */
 gchar *cf_get_display_name(capture_file *cf);
 
+/**
+ * Get a name that can be used to generate a file name from the
+ * capture file name.  It's based on the displayable name, so it's
+ * UTF-8; if it ends with a suffix that's used by a file type libwiretap
+ * can read, we strip that suffix off.
+ *
+ * @param cf the capture file
+ * @return the base name (must be g_free'd)
+ */
+gchar *cf_get_basename(capture_file *cf);
+
 /**
  * Set the source of the capture data for temporary files, e.g.
  * "Interface eth0" or "Pipe from Pong"
@@ -606,13 +610,6 @@ void cf_select_packet(capture_file *cf, int row);
  */
 void cf_unselect_packet(capture_file *cf);
 
-/**
- * Unselect all protocol tree fields, if any.
- *
- * @param cf the capture file
- */
-void cf_unselect_field(capture_file *cf);
-
 /**
  * Mark a particular frame in a particular capture.
  *
@@ -718,18 +715,6 @@ guint32 cf_comment_types(capture_file *cf);
  */
 gboolean cf_add_ip_name_from_string(capture_file *cf, const char *addr, const char *name);
 
-#ifdef WANT_PACKET_EDITOR
-/**
- * Give a frame new, edited data.
- *
- * @param cf the capture file
- * @param fd frame_data structure for the frame
- * @param phdr the struct wtap_pkthdr for the frame
- * @param pd the raw packet data for the frame
- */
-void cf_set_frame_edited(capture_file *cf, frame_data *fd, struct wtap_pkthdr *phdr, guint8 *pd);
-#endif
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
@@ -152,13 +145,13 @@ cf_read_status_t cf_read(capture_file *cf, gboolean from_save);
  * @param cf the capture file from which to read the record
  * @param fdata the frame_data structure for the record in question
- * @param phdr pointer to a wtap_pkthdr structure to contain the
+ * @param rec pointer to a wtap_rec structure to contain the
  * record's metadata
  * @param buf a Buffer into which to read the record's raw data